=======
Credits
=======

Development Lead
----------------

* Tasos Katsoulas <akatsoulas@mozilla.com>
* John Giannelos <jgiannelos@mozilla.com>

Contributors
------------

None yet. Why not be the first?
